# OrderActionRatePlanOrderActionType

Type of the order action.

## Enum

* `ADDPRODUCT` (value: `'AddProduct'`)

* `UPDATEPRODUCT` (value: `'UpdateProduct'`)

* `REMOVEPRODUCT` (value: `'RemoveProduct'`)

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


